@@ -1,6 +1,24 @@
 require 'spec_helper_acceptance'
 
-describe "ntp class:" do
+case fact('osfamily')
+when 'FreeBSD'
+  packagename = 'net/ntp'
+when 'Gentoo'
+  packagename = 'net-misc/ntp'
+when 'Linux'
+  case fact('operatingsystem')
+  when 'ArchLinux'
+    packagename = 'ntp'
+  when 'Gentoo'
+    packagename = 'net-misc/ntp'
+  end
+when 'AIX'
+  packagename = 'bos.net.tcp.client'
+else
+  packagename = 'ntp'
+end
+
+describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   it 'applies successfully' do
     pp = "class { 'ntp': }"
 
@@ -32,8 +50,9 @@ describe "ntp class:" do
 
   describe 'config_template' do
     it 'sets up template' do
-      shell('mkdir -p /etc/puppet/modules/test/templates')
-      shell('echo "testcontent" >> /etc/puppet/modules/test/templates/ntp.conf')
+      modulepath = default['distmoduledir']
+      shell("mkdir -p #{modulepath}/test/templates")
+      shell("echo 'testcontent' >> #{modulepath}/test/templates/ntp.conf")
     end
 
     it 'sets the ntp.conf location' do
@@ -66,10 +85,13 @@ describe "ntp class:" do
         keys_enable     => true,
         keys_file       => '/etc/ntp/keys',
         keys_controlkey => '/etc/ntp/controlkey',
-        keys_requestkey => '/etc/ntp/requestkey',
-        keys_trusted    => [ '/etc/ntp/key1', '/etc/ntp/key2' ],
+        keys_requestkey => '1',
+        keys_trusted    => [ '1', '2' ],
       }
       EOS
+      # Rely on a shell command instead of a file{} here to avoid loops
+      # within puppet when it tries to manage /etc/ntp/keys before /etc/ntp.
+      shell("mkdir -p /etc/ntp && echo '1 M AAAABBBB' >> /etc/ntp/keys")
       apply_manifest(pp, :catch_failures => true)
     end
 
@@ -77,8 +99,8 @@ describe "ntp class:" do
       it { should be_file }
       it { should contain 'keys /etc/ntp/keys' }
       it { should contain 'controlkey /etc/ntp/controlkey' }
-      it { should contain 'requestkey /etc/ntp/requestkey' }
-      it { should contain 'trustedkey /etc/ntp/key1 /etc/ntp/key2' }
+      it { should contain 'requestkey 1' }
+      it { should contain 'trustedkey 1 2' }
     end
   end
 
@@ -87,13 +109,13 @@ describe "ntp class:" do
       pp = <<-EOS
       class { 'ntp':
         package_ensure => present,
-        package_name   => ['ntp'],
+        package_name   => ['#{packagename}'],
       }
       EOS
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe package('ntp') do
+    describe package(packagename) do
       it { should be_installed }
     end
   end
