@@ -1,6 +1,6 @@
 require 'spec_helper_acceptance'
 
-describe 'preferred servers' do
+describe 'preferred servers', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   pp = <<-EOS
       class { '::ntp':
         servers           => ['a', 'b', 'c', 'd'],
