@@ -1,6 +1,6 @@
 require 'spec_helper_acceptance'
 
-describe "ntp class with restrict:" do
+describe "ntp class with restrict:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   context 'should run successfully' do
     pp = "class { 'ntp': restrict => ['test restrict']}"
 
